



******

Bravo!  You have received a Mercantilism Diploma in "apoplast" from   
the Orbital Convergence University International Air and Water 
Embassy of the Tangerine Planet 🍊 (the planet that is one ellipse further from
the Sun than Earth's ellipse).

You are now officially certified to include "apoplast" in your practice!

Encore! Encore! Encore! Encore!

******


# apoplast

---

## description


---		
		
## 🎁 obtainment
`[xonsh] pip install apoplast`

---

## tutorial
`[xonsh] apoplast`

---

## contacts
Bryan@Status600.com





